==> kazehakase-0.4.7.tar.gz: kazehakase-0.4.7/module/embed/gecko/kz-gecko-single.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */

/*
 *  Copyright (C) 2007 Hiroyuki Ikezoe
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2, or (at your option)
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef __KZ_GECKO_SINGLE_H__
#define __KZ_GECKO_SINGLE_H__

#include <glib-object.h>
#include <gtkmozembed.h>
#include "kazehakase.h"

G_BEGIN_DECLS

#define KZ_TYPE_GECKO_SINGLE		(kz_gecko_single_get_type ())
#define KZ_GECKO_SINGLE(obj)		(G_TYPE_CHECK_INSTANCE_CAST ((obj), KZ_TYPE_GECKO_SINGLE, KzGeckoSingle))
#define KZ_GECKO_SINGLE_CLASS(klass)	(G_TYPE_CHECK_CLASS_CAST ((klass), KZ_TYPE_GECKO_SINGLE, KzGeckoSingleClass))
#define KZ_IS_GECKO_SINGLE(obj)		(G_TYPE_CHECK_INSTANCE_TYPE ((obj), KZ_TYPE_GECKO_SINGLE))
#define KZ_IS_GECKO_SINGLE_CLASS(klass)	(G_TYPE_CHECK_CLASS_TYPE ((klass), KZ_TYPE_GECKO_SINGLE))
#define KZ_GECKO_SINGLE_GET_CLASS(obj)	(G_TYPE_INSTANCE_GET_CLASS ((obj), KZ_TYPE_GECKO_SINGLE, KzGeckoSingleClass))

typedef struct _KzGeckoSingle	KzGeckoSingle;
typedef struct _KzGeckoSingleClass	KzGeckoSingleClass;

struct _KzGeckoSingle
{
	GtkMozEmbedSingle parent;
};

struct _KzGeckoSingleClass
{
	GtkMozEmbedSingleClass parent_class;
};


GType          kz_gecko_single_get_type              (void);
KzGeckoSingle *kz_gecko_single_new                   (KzApp *kz_app);

G_END_DECLS

#endif /* __KZ_GECKO_SINGLE_H__ */

==> kazehakase_0.5.8.orig.tar.gz: kazehakase-0.5.8/module/embed/gecko/kz-gecko-single.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */

/*
 *  Copyright (C) 2007 Hiroyuki Ikezoe
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2, or (at your option)
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef __KZ_GECKO_SINGLE_H__
#define __KZ_GECKO_SINGLE_H__

#include <glib-object.h>
#include <gtkmozembed.h>
#include "kazehakase.h"

G_BEGIN_DECLS

#define KZ_TYPE_GECKO_SINGLE		(kz_gecko_single_get_type ())
#define KZ_GECKO_SINGLE(obj)		(G_TYPE_CHECK_INSTANCE_CAST ((obj), KZ_TYPE_GECKO_SINGLE, KzGeckoSingle))
#define KZ_GECKO_SINGLE_CLASS(klass)	(G_TYPE_CHECK_CLASS_CAST ((klass), KZ_TYPE_GECKO_SINGLE, KzGeckoSingleClass))
#define KZ_IS_GECKO_SINGLE(obj)		(G_TYPE_CHECK_INSTANCE_TYPE ((obj), KZ_TYPE_GECKO_SINGLE))
#define KZ_IS_GECKO_SINGLE_CLASS(klass)	(G_TYPE_CHECK_CLASS_TYPE ((klass), KZ_TYPE_GECKO_SINGLE))
#define KZ_GECKO_SINGLE_GET_CLASS(obj)	(G_TYPE_INSTANCE_GET_CLASS ((obj), KZ_TYPE_GECKO_SINGLE, KzGeckoSingleClass))

typedef struct _KzGeckoSingle	KzGeckoSingle;
typedef struct _KzGeckoSingleClass	KzGeckoSingleClass;

struct _KzGeckoSingle
{
	GObject parent;
};

struct _KzGeckoSingleClass
{
	GObjectClass parent_class;
};


GType          kz_gecko_single_get_type              (void);
KzGeckoSingle *kz_gecko_single_new                   (KzApp *kz_app);

G_END_DECLS

#endif /* __KZ_GECKO_SINGLE_H__ */
